#[repr(u8)]pub enum DtcmWrRdSel {
DTCM_WR_RD_SEL_0 = 0,
DTCM_WR_RD_SEL_1 = 1,
}Variants
DTCM_WR_RD_SEL_0 = 0
When DTCM read access hits magic address, it will generate interrupt.
DTCM_WR_RD_SEL_1 = 1
When DTCM write access hits magic address, it will generate interrupt.
Implementations
Sourceimpl DtcmWrRdSel
impl DtcmWrRdSel