#[repr(u8)]pub enum ItcmWrRdSel {
ITCM_WR_RD_SEL_0 = 0,
ITCM_WR_RD_SEL_1 = 1,
}Variants
ITCM_WR_RD_SEL_0 = 0
When ITCM read access hits magic address, it will generate interrupt.
ITCM_WR_RD_SEL_1 = 1
When ITCM write access hits magic address, it will generate interrupt.
Implementations
Sourceimpl ItcmWrRdSel
impl ItcmWrRdSel