#[repr(u8)]pub enum OcramWrRdSel {
OCRAM_WR_RD_SEL_0 = 0,
OCRAM_WR_RD_SEL_1 = 1,
}Variants
OCRAM_WR_RD_SEL_0 = 0
When OCRAM read access hits magic address, it will generate interrupt.
OCRAM_WR_RD_SEL_1 = 1
When OCRAM write access hits magic address, it will generate interrupt.
Implementations
Sourceimpl OcramWrRdSel
impl OcramWrRdSel